psychopy_ext.fmri.make_roi_pattern — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.fmri.make_roi_pattern

`psychopy_ext.fmri.` `make_roi_pattern`(rois)
  Takes ROI names and expands them into a list of:

    - ROI name as given

    - Pretty ROI name for output

    - ROI names with * prepended and appended for finding these ROIs easily

        using glob

  Args: | rois (list of str or tuples): A list of ROI names, e.g., [‘V1’, ([‘rh_V2’,’lh_V2’], ‘V2’)]. If an element is a tuple, the first element is ROI names and the second one is their “pretty” (unifying) name for printing.
  Returns: | A list of ROI names in the format described above, e.g. [(‘V1’,’V1’,’*V1*’), ([‘rh_V2’,’lh_V2’], ‘V2’, [‘*rh_V2*’,’*lh_V2*’])]